@@ -546,8 +546,9 @@ while ($row = $db->fetchRow($res)) {
         if (142 > $verzija) {
             try {
                 $db->ChangeDatabase(DB_WARPIT_WEBCATI);
-                $sql = "INSERT INTO `" . $tbl . "` (`q_pos`, `q_name`, `tip_sql`, `disable_question`) VALUES (-3, '_Repeal', 5, 1);";
+$sql = "INSERT INTO `" . $tbl . "` (`q_pos`, `q_name`, `tip_sql`, `disable_question`) VALUES (-3, '_Repeal', 5, 1);";
                 $db->SQLexecute($sql);
+
             } catch (Exception $e) {
                 if (SHOW_LOG_MESSAGES) {
                     var_dump($e->getMessage());
@@ -676,7 +677,7 @@ while ($row = $db->fetchRow($res)) {
 
         if (142 > $verzija) {
             try {
-                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
+                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
                 $sql = "ALTER TABLE `{$tbl}`
 	                      ADD COLUMN `input_types` VARCHAR(255) NULL AFTER `anonymize`";
                 $db->SQLexecute($sql);
@@ -729,6 +730,20 @@ while ($row = $db->fetchRow($res)) {
             echo "$tbl SUCCESSFUL!<br>";
         }
 
+        if (142 > $verzija) {
+            try {
+                $db->ChangeDatabase(DB_WARPIT_WEBCATI);
+                $sql = "ALTER TABLE `{$tbl}`
+	                      ADD COLUMN `autoSubmitTimeout` INT NOT NULL DEFAULT '100' AFTER `autoSubmit`";
+                $db->SQLexecute($sql);
+            } catch (Exception $e) {
+                if (SHOW_LOG_MESSAGES) {
+                    var_dump($e->getMessage());
+                    echo "<br><font color=red>Table " . $tbl . " can not be modified with autoSubmitTimeout column!</font><br>";
+                }
+            }
+        }
+
         if (142 > $verzija) {
             try {
                 $db->ChangeDatabase(DB_WARPIT_WEBCATI);
@@ -901,6 +916,40 @@ while ($row = $db->fetchRow($res)) {
             echo "$tbl SUCCESSFUL!<br>";
         }
     } catch (Exception $e) {
+        if (142 > $verzija) {
+            try {
+                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
+                $sql = "ALTER TABLE `{$tbl}___EngineLog` ADD INDEX `id_user_user_type_activeRecord` (`id_user`, `user_type`, `activeRecord`);";
+
+                $db->SQLexecute($sql);
+            } catch (Exception $e) {
+                if (SHOW_LOG_MESSAGES) {
+                    var_dump($e->getMessage());
+                    echo "<br><font color=red>Table " . $tbl . " can not be modified: add id_user_user_type_activeRecord index on EngineLog</font><br>";
+                }
+            }
+        }
+
+        if (142 > $verzija) {
+            try {
+                $db->ChangeDatabase(DB_WARPIT_WEBCATI_BASE);
+                $sql = "ALTER TABLE `" . $tbl . "___EngineLog`
+	                               ADD INDEX `id_user_user_type` (`id_user`, `user_type`)";
+
+                $db->SQLexecute($sql);
+            } catch (Exception $e) {
+                if (SHOW_LOG_MESSAGES) {
+                    var_dump($e->getMessage());
+                    echo "<br><font color=red>Table " . $tbl . "___EngineLog can not be modified: index on id_user-user_type</font><br>";
+                }
+            }
+        }
+
+        if (SHOW_LOG_MESSAGES) {
+            echo "$tbl SUCCESSFUL!<br>";
+        }
+    }
+    catch (Exception $e) {
         if (SHOW_LOG_MESSAGES) {
             print_r($e->getMessage());
             echo "<br><br><br>";
