@@ -307,6 +307,18 @@ class telTableManager extends GridDataManipulator
 				return $this->arr;
 	}
 
+	public function selectAction()
+    {
+        $srcfields = json_decode( stripslashes($_POST['srcfields'])  );
+
+        //we replace aliased column structureId => c.id
+        $structureIdKey = array_search('c.structureId',$srcfields);
+        $srcfields[$structureIdKey] = 'c.id';
+
+        $_POST['srcfields'] = json_encode($srcfields);
+
+        return parent::selectAction();
+    }
 
 	protected function replaceStructureIdInSearchField()
     {
