@@ -251,15 +251,22 @@ class telManagmentManipulator extends TreeDataManipulator
 				KEY proj_status_rec (proj_status_rec),
 				KEY proj_status (proj_status)) ENGINE=MyISAM DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci";
         }
+
+
         $sql[] = $create_telbase;
         //we increase order in tree (!!!NEW!!!) for this parent only!!!!
         $sql[] = "UPDATE $this->table SET orderBy = orderBy+1 WHERE orderBy >= $orderTree AND id_sup = $parent";
+
         $sql[] = "INSERT INTO $this->table(id_sup,orderBy,name,is_leaf) VALUES( $parent ,$orderTree,'$text',true ) ";
-   
+
+
         foreach ($sql as $sqlStatemens) {
-            if ( !$this->db->SQLexecute($sqlStatemens) ) {
+            if (!$this->db->SQLexecute($sqlStatemens)) {
+
+
                 return '{success:false,error:"'.$this->db->GetError().'", STATEMENT: "'.$sqlStatemens.'"}';
             }
+
         }
         $id = $this->db->GetLastInsertId();
         return '{success:true,insertId:'.$id .'}';
@@ -381,24 +388,23 @@ class telManagmentManipulator extends TreeDataManipulator
                 return '{success:false,error:"Telephone table ID problem"}';
             }
             $sql = "SELECT name FROM ".$this->table." WHERE id = ".$nodeId;
-            if ( !$rs = $this->db->SQLexecute($sql) ) {	
-                return '{success:false,error:"'.$this->db->GetError().'", STATEMENT: "'.$sqlStatemens.'"}';	
-            }
-            $row = $this->db->fetchArray($rs);
+            if ( !$rs = $this->db->SQLexecute($sql) ) {
+                return '{success:false,error:"'.$this->db->GetError().'", STATEMENT: "'.$sqlStatemens.'"}';
+            }$row = $this->db->fetchArray($rs);
             $tName = $tablePrefix.$row[0];
-            
-            $sql = "SELECT id_import FROM ".$tName." WHERE proj_reserved > 0 LIMIT 1";                      
-            $AllowToDeleteRes = $this->db->SQLexecute($sql);           
+            $sql = "SELECT id_import FROM ".$tName." WHERE proj_reserved > 0 LIMIT 1";
+            $AllowToDeleteRes = $this->db->SQLexecute($sql);
             if ( $this->db->NumRows($AllowToDeleteRes) ) {
                 return '{success:false,error:"You cannot delete telephone table with project reserved numbers"}';
             }
-        
+
             If ( !$this->db->SQLexecute("DROP TABLE  `$tName`") ) {
                 return '{success:false,error:"'.$this->db->GetError().'", STATEMENT: "'.$sqlStatemens.'"}';
             }
 
             $sqlStatemens = "DELETE FROM $this->tableAddon WHERE id_telbaza = ".$_POST['nodeId'];
-            if ( !$this->db->SQLexecute($sqlStatemens) ) {
+            if (!$this->db->SQLexecute($sqlStatemens)) {
+
                 return '{success:false,error:"'.$this->db->GetError().'", STATEMENT: "'.$sqlStatemens.'"}';
             }
 
@@ -848,4 +854,4 @@ else
 }
 
 
-?>
\ No newline at end of file
+?>
